---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: feature-request
assignees: ''

---

### Current situation

A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]; Currently there is no way of [...]

### Desired Situation

What functionality should become possible or easier?

### Proposed implementation

How would you implement the new feature? Did you consider alternative implementations?
You can start by describing interface changes like a new argument or a new function. There is no need to get too detailed here.
